@@ -3,65 +3,65 @@
 # agreement statistics for two raters
 immer_agree2 <- function( y , w = rep(1,nrow(y) ) ,
 		symmetrize = FALSE , tol= c(0,1) ){		
-	CALL <- base::match.call()
+	CALL <- match.call()
 	res <- immer_unique_patterns( dat = y , w=w )
 	y <- res$y
 	w <- res$w
 	#***
 	# symmetrize frequency table
 	if ( symmetrize ){
-		y <- base::rbind( y , y[,c(2,1) ] )
-		w <- base::c( w/2 , w/2 )
+		y <- rbind( y , y[,c(2,1) ] )
+		w <- c( w/2 , w/2 )
 		res <- immer_unique_patterns( dat = y , w=w )
 		y <- res$y
 		w <- res$w    
 	}
-	w0 <- w / base::sum(w)
+	w0 <- w / sum(w)
 
 	#*** create frequency table
-	categs <- base::unique( base::c( y[,1] , y[,2] ) )
-	CC <- base::length(categs)
+	categs <- unique( c( y[,1] , y[,2] ) )
+	CC <- length(categs)
 
-	agree_table <- base::matrix( 0 , nrow=CC , ncol=CC)
+	agree_table <- matrix( 0 , nrow=CC , ncol=CC)
 	for (ii in 1:CC){
 		for (jj in 1:CC){
-			agree_table[ii,jj] <- base::sum( ( y[,1] == categs[ii] ) * 
+			agree_table[ii,jj] <- sum( ( y[,1] == categs[ii] ) * 
 					( y[,2] == categs[jj] ) * w0 )
 		}
 	}
 	
-	base::rownames(agree_table) <- base::paste0( base::colnames(y)[1] , "_Cat" , categs)
-	base::colnames(agree_table) <- base::paste0( base::colnames(y)[2] , "_Cat" , categs)
+	rownames(agree_table) <- paste0( colnames(y)[1] , "_Cat" , categs)
+	colnames(agree_table) <- paste0( colnames(y)[2] , "_Cat" , categs)
 
 	#****
 	# compute absolute agreement (with tolerance specified in vector)
-	TT <- base::length(tol)
-	agree_raw <- base::rep(NA,TT)
-	base::names(agree_raw) <- base::paste0("tol" , tol)
+	TT <- length(tol)
+	agree_raw <- rep(NA,TT)
+	names(agree_raw) <- paste0("tol" , tol)
 	for (tt in 1:TT){
 		# tt <- 1
-		agree_raw[tt] <- base::sum( w0[ base::abs( y[,1] - y[,2] ) <= tol[tt] ]  )
+		agree_raw[tt] <- sum( w0[ abs( y[,1] - y[,2] ) <= tol[tt] ]  )
 					}
 
 	#*** marginal probabilities
-	marg <- base::matrix( 0 , nrow=3 , ncol=CC)
-	base::rownames(marg) <- base::c( base::colnames(y) , "Mean" )
-	base::colnames(marg) <- base::paste0( "Cat" , categs )
-	marg[1,] <- base::rowSums( agree_table )
-	marg[2,] <- base::colSums( agree_table )
+	marg <- matrix( 0 , nrow=3 , ncol=CC)
+	rownames(marg) <- c( colnames(y) , "Mean" )
+	colnames(marg) <- paste0( "Cat" , categs )
+	marg[1,] <- rowSums( agree_table )
+	marg[2,] <- colSums( agree_table )
 	marg[3,] <- ( marg[1,] + marg[2,] ) / 2
 
 	#*** overall agreement
-	Pa <- base::sum( base::diag( agree_table ) )
+	Pa <- sum( diag( agree_table ) )
 
 	#**** chance agreement
-	Pe <- base::c()
+	Pe <- c()
 	# Scott's Pi
-	Pe["pi"] <- base::sum( marg[3,]^2 )
+	Pe["pi"] <- sum( marg[3,]^2 )
 	# Cohen's kappa
-	Pe["kappa"] <- base::sum( marg[1,] * marg[2,] )
+	Pe["kappa"] <- sum( marg[1,] * marg[2,] )
 	# AC1 Gwet
-	Pe["AC1"] <- base::sum( marg[3,] * ( 1 - marg[3,] ) ) / ( CC - 1 )
+	Pe["AC1"] <- sum( marg[3,] * ( 1 - marg[3,] ) ) / ( CC - 1 )
 
 	#*** algorithm Aicken's alpha
 	PAk <- marg[1,]
@@ -74,9 +74,9 @@ immer_agree2 <- function( y , w = rep(1,nrow(y) ) ,
 	PAH <- res0$PAH
 	PBH <- res0$PBH
 	# hard to classify probs
-	PH <- base::matrix( 0 , nrow=2 , ncol=CC )
-	base::colnames(PH) <- base::colnames(marg)
-	base::rownames(PH) <- base::rownames(marg)[1:2]
+	PH <- matrix( 0 , nrow=2 , ncol=CC )
+	colnames(PH) <- colnames(marg)
+	rownames(PH) <- rownames(marg)[1:2]
 	PH[1,] <- PAH
 	PH[2,] <- PBH
 
@@ -85,17 +85,17 @@ immer_agree2 <- function( y , w = rep(1,nrow(y) ) ,
 		
 	#-----
 	# output
-	res <- base::list( "agree_raw" = agree_raw ,
+	res <- list( "agree_raw" = agree_raw ,
 			"agree_stats" = agree_stats ,
 			"agree_table" = agree_table ,
 			"marg" = marg , 
 			"Pe" = Pe , "Pa" = Pa , 
 			"alpha" = res0$alpha	, "PH" = PH,
-			"nobs" = base::sum(w) , "ncat" = CC , "tol" = tol , 
+			"nobs" = sum(w) , "ncat" = CC , "tol" = tol , 
 			"y" = y , "w" = w , 
 			"CALL" = CALL
 			)
-	base::class(res) <- "immer_agree2"
-	base::return(res)
+	class(res) <- "immer_agree2"
+	return(res)
 }
-#############################################################
\ No newline at end of file
+#############################################################
