@@ -5,11 +5,11 @@ logLik.immer_HRM <- function (object, ...) {
 	# extract log-likelihood
 	out <- object$like
     # number of parameters
-    base::attr(out, "df") <- base::sum(object$ic$Npars)
+    attr(out, "df") <- sum(object$ic$Npars)
 	# extract number of observations
-    base::attr(out, "nobs") <- object$ic$N
-    base::class(out) <- "logLik"
-    base::return(out)
+    attr(out, "nobs") <- object$ic$N
+    class(out) <- "logLik"
+    return(out)
 }
 #################################################################
 
@@ -21,10 +21,10 @@ logLik.immer_cml <- function (object, ...) {
 	# extract log-likelihood
 	out <- object$loglike
     # number of parameters
-    base::attr(out, "df") <- base::sum(object$npars)
+    attr(out, "df") <- sum(object$npars)
 	# extract number of observations
-    base::attr(out, "nobs") <- object$N
-    base::class(out) <- "logLik"
-    base::return(out)
+    attr(out, "nobs") <- object$N
+    class(out) <- "logLik"
+    return(out)
 }
-#################################################################
\ No newline at end of file
+#################################################################
