@@ -1,6 +1,6 @@
 
 plot.immer_HRM <- function( x , ... ){
-	base::class(x) <- "mcmc.sirt"
+	class(x) <- "mcmc.sirt"
 	graphics::plot( x , ... )
 }
 	
